==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/photos/l10n/uk.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Світлини",
    "Your memories under your control" : "Ваші спогади під особистим контролем",
    "All media" : "Усі медіа",
    "Videos" : "Відео",
    "Albums" : "Альбоми",
    "Collaborative albums" : "Спільні альбоми",
    "People" : "Люди",
    "Folders" : "Каталоги",
    "Favorites" : "Улюблене",
    "On this day" : "Цього дня",
    "Shared with you" : "Вам надано доступ",
    "Tags" : "Позначки",
    "Locations" : "Розташування",
    "Photos settings" : "Налаштування фотографій",
    "Mark selection as favorite" : "Позначити вибране як вибране",
    "Add selection to favorites" : "Додайте вибір до вибраного",
    "Remove selection from favorites" : "Видалити вибір із вибраного",
    "Name of the album" : "Назва альбому",
    "Location of the album" : "Розташування альбому",
    "Go back to the previous view." : "Повернутися до попереднього перегляду.",
    "Back" : "Назад",
    "Go to the add collaborators view." : "Перейдіть до перегляду додавання співавторів.",
    "Add collaborators" : "Додайте співавторів",
    "Save." : "Зберегти.",
    "Create the album." : "Створіть альбом.",
    "Save" : "Зберегти",
    "Create album" : "Створити альбом",
    "Back to the new album form." : "Повернутися до форми нового альбому.",
    "Add to Album" : "Додати в альбом",
    "Add selection to album {ablumName}" : "Додати виділення до альбому {ablumName}",
    "Create a new album." : "Створіть новий альбом.",
    "Create new album" : "Створити новий альбом",
    "New album" : "Новий альбом",
    "_%n item_::_%n photos and videos_" : ["%n фотографії та відео","%n фотографії та відео","%n фотографії та відео","%n фотографії та відео"],
    "_Share with %n user_::_Share with %n users_" : ["Поділіться з %n користувачем","Поділіться з %n користувачами","Поділіться з %n користувачами","Поділіться з %n користувачами"],
    "Add people or groups who can edit your album" : "Додайте людей або групи, які можуть редагувати ваш альбом",
    "Search for collaborators" : "Пошук співавторів",
    "Search people or groups" : "Пошук людей або груп",
    "Add {collaboratorLabel} to the collaborators list" : "Додайте {collaboratorLabel} до списку співавторів",
    "No collaborators available" : "Співавторів немає",
    "Remove {collaboratorLabel} from the collaborators list" : "Видалити {collaboratorLabel} зі списку співавторів",
    "Public link copied!" : "Публічне посилання скопійовано!",
    "Copy public link" : "Копіювати публічне посилання",
    "Share via public link" : "Поділіться через публічне посилання",
    "Failed to fetch collaborators list." : "Не вдалося отримати список співавторів.",
    "This collection does not exist" : "Ця колекція не існує",
    "An error occurred" : "Виникла помилка",
    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
    "Select image {imageName}" : "Виберіть зображення {imageName}",
    "The file is in the favorites" : "Файл знаходиться в обраному",
    "Open the full size \"{name}\" image" : "Відкрити повнорозмірне зображення: \"{name}\"",
    "There are no photos or videos yet!" : "Ще немає фото чи відео!",
    "Add to {destination}" : "Додати до {destination}",
    "Open the \"{name}\" sub-directory" : "Відкрити підкаталог \"{name}\"",
    "Back to {folder}" : "Повернутися до каталогу {folder}",
    "Share this folder" : "Надати спільний доступ до каталогу",
    "_{years} year ago_::_{years} years ago_" : ["{years} рік тому","{years} років тому","{years} років тому","{years} років тому"],
    "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
    "Default Photos upload and Albums location" : "Розташування завантаження фотографій і альбомів за умовчанням",
    "Select the default location for your media" : "Виберіть розташування за умовчанням для медіа",
    "Invalid location selected" : "Вибрано недійсне місце розташування",
    "View" : "Перегляд",
    "Photos directory" : "Каталог фотографій",
    "_%n photo_::_%n photos_" : ["%n фото","%n фото","%n фото","%n фото"],
    "Manage collaborators for this album" : "Керуйте співавторами для цього альбому",
    "Open actions menu" : "Відкрити меню дій",
    "Edit album details" : "Редагувати деталі альбому",
    "Download all files in album" : "Завантажити всі файли в альбомі",
    "Delete album" : "Видалити альбом",
    "Download selected files" : "Завантажте вибрані файли",
    "Remove selection from album" : "Видалити виділення з альбому",
    "This album does not have any photos or videos yet!" : "У цьому альбомі ще немає фото чи відео!",
    "Add photos to this album" : "Додайте фотографії до цього альбому",
    "Add photos to the album" : "Додайте фотографії в альбом",
    "Manage collaborators" : "Керуйте співавторами",
    "Save collaborators for this album." : "Зберегти співавторів для цього альбому.",
    "Cover photo for album {albumName}" : "Обкладинка для альбому {albumName}",
    "There is no album yet!" : "Альбому ще немає!",
    "This person could not be found" : "Цю людину не вдалося знайти",
    "Rename person" : "Перейменувати особу",
    "Merge with different person" : "Злитися з іншою людиною",
    "Download selected photos" : "Завантажте вибрані фото",
    "Favorite" : "До улюблених",
    "Remove from favorites" : "Вилучено з улюбленого",
    "Remove person" : "Видалити особу",
    "Name of this person" : "Ім'я цієї людини",
    "Merge person" : "Об’єднати особу",
    "_Remove photo from person_::_Remove photos from person_" : ["Видалити фото з особи","Видалити фотографії з особи","Видалити фотографії з особи","Видалити фотографії з особи"],
    "This might take some time depending on the size of your photo library." : "Це може зайняти деякий час залежно від розміру вашої бібліотеки фотографій.",
    "Recognized people will show up here" : "Тут відображатимуться розпізнані люди",
    "This folder does not exist" : "Цей каталог не існує",
    "Loading folders …" : "Завантаження папок…",
    "No photos in here" : "Тут немає світлин",
    "Shared albums" : "Альбоми із спільним доступом",
    "Cover photo for shared album {albumName}." : "Обкладинка для спільного альбому {albumName}.",
    "Back to tags overview" : "Назад до огляду тегів",
    "No photos with this tag yet" : "Фотографій із цим тегом ще немає",
    "No tags yet" : "Ще немає позначок",
    "Photos with tags will show up here" : "Світлини з позначками буде показано тут",
    "Popular tags" : "Популярні теги",
    "Add" : "Додати",
    "Create a new album" : "Створіть новий альбом",
    "Add selection to an album" : "Додайте виділене в альбом",
    "Add to album" : "Додати в альбом",
    "Delete selection" : "Видалити виділення",
    "Failed to fetch faces list." : "Не вдалося отримати список облич.",
    "All your media" : "Усі ваші медіа",
    "Tagged photos" : "Світлини з позначками",
    "Failed to create {albumName}." : "Не вдалося створити {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Не вдалося перейменувати {currentAlbumName} на {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Не вдалося перейменувати {oldName} на {faceName}.",
    "Failed to delete {faceName}." : "Не вдалося видалити {faceName}.",
    "Failed to delete {fileId}." : "Не вдалося видалити {fileId}.",
    "Failed to delete {fileName}." : "Не вдалося видалити {fileName}.",
    "Failed to set favorite state for {fileId}." : "Не вдалося встановити улюблений стан для {fileId}.",
    "Failed to set favorite state for {fileName}." : "Не вдалося встановити улюблений стан для {fileName}.",
    "Your photos" : "Ваші світлини",
    "Your videos" : "Ваші відео",
    "Your folders" : "Ваші каталоги",
    "Settings" : "Налаштування"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/photos/l10n/uk.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Публічне посилання",
    "Photos" : "Світлини",
    "Your memories under your control" : "Ваші спогади під особистим контролем",
    "All media" : "Усі зображення та відео",
    "Videos" : "Відео",
    "Albums" : "Альбоми",
    "Collaborative albums" : "Спільні альбоми",
    "People" : "Люди",
    "Folders" : "Каталоги",
    "Favorites" : "Улюблене",
    "On this day" : "Цього дня",
    "Shared with you" : "Вам надано доступ",
    "Tags" : "Позначки",
    "Locations" : "Розташування",
    "Photos settings" : "Налаштування фотографій",
    "Mark selection as favorite" : "Позначити вибране як вибране",
    "Add selection to favorites" : "Додайте вибір до вибраного",
    "Remove selection from favorites" : "Видалити вибір із вибраного",
    "Name of the album" : "Назва альбому",
    "Location of the album" : "Розташування альбому",
    "Go back to the previous view." : "Повернутися до попереднього перегляду.",
    "Back" : "Назад",
    "Go to the add collaborators view." : "Перейдіть до перегляду додавання співавторів.",
    "Add collaborators" : "Додайте співавторів",
    "Save." : "Зберегти.",
    "Create the album." : "Створіть альбом.",
    "Save" : "Зберегти",
    "Create album" : "Створити альбом",
    "Back to the new album form." : "Повернутися до форми нового альбому.",
    "Add to Album" : "Додати в альбом",
    "Create a new album." : "Створіть новий альбом.",
    "Create new album" : "Створити новий альбом",
    "New album" : "Новий альбом",
    "_%n item_::_%n photos and videos_" : ["%n фотографії та відео","%n фотографії та відео","%n фотографії та відео","%n фотографії та відео"],
    "_Share with %n user_::_Share with %n users_" : ["Поділіться з %n користувачем","Поділіться з %n користувачами","Поділіться з %n користувачами","Поділіться з %n користувачами"],
    "Add people or groups who can edit your album" : "Додайте людей або групи, які можуть редагувати ваш альбом",
    "Search for collaborators" : "Пошук співавторів",
    "Search people or groups" : "Пошук людей або груп",
    "Add {collaboratorLabel} to the collaborators list" : "Додайте {collaboratorLabel} до списку співавторів",
    "No collaborators available" : "Співавторів немає",
    "Remove {collaboratorLabel} from the collaborators list" : "Видалити {collaboratorLabel} зі списку співавторів",
    "Copy the public link" : "Копіювати публічне посилання",
    "Public link copied!" : "Публічне посилання скопійовано!",
    "Copy public link" : "Копіювати публічне посилання",
    "Delete the public link" : "Вилучити публічне посилання",
    "Share via public link" : "Поділіться через публічне посилання",
    "Failed to fetch collaborators list." : "Не вдалося отримати список співавторів.",
    "Failed to fetch album." : "Не вдалося отримати альбом.",
    "Failed to update album." : "Не вдалося оновити альбом.",
    "This collection does not exist" : "Ця колекція не існує",
    "An error occurred" : "Виникла помилка",
    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
    "Select image {imageName}" : "Виберіть зображення {imageName}",
    "The file is in the favorites" : "Файл знаходиться в обраному",
    "Open the full size \"{name}\" image" : "Відкрити повнорозмірне зображення: \"{name}\"",
    "There are no photos or videos yet!" : "Ще немає фото чи відео!",
    "Add to {destination}" : "Додати до {destination}",
    "Open the \"{name}\" sub-directory" : "Відкрити підкаталог \"{name}\"",
    "Back to {folder}" : "Повернутися до каталогу {folder}",
    "Share this folder" : "Надати спільний доступ до каталогу",
    "_{years} year ago_::_{years} years ago_" : ["{years} рік тому","{years} років тому","{years} років тому","{years} років тому"],
    "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
    "Default Photos upload and Albums location" : "Розташування завантаження фотографій і альбомів за умовчанням",
    "Select the default location for your media" : "Виберіть типове розташування для ваших зображень та відео",
    "Invalid location selected" : "Вибрано недійсне місце розташування",
    "View" : "Перегляд",
    "Photos directory" : "Каталог фотографій",
    "_%n photo_::_%n photos_" : ["%n фото","%n фото","%n фото","%n фото"],
    "Manage collaborators for this album" : "Керуйте співавторами для цього альбому",
    "Open actions menu" : "Відкрити меню дій",
    "Edit album details" : "Редагувати деталі альбому",
    "Download all files in album" : "Завантажити всі файли в альбомі",
    "Delete album" : "Видалити альбом",
    "Download selected files" : "Завантажте вибрані файли",
    "Remove selection from album" : "Видалити виділення з альбому",
    "This album does not have any photos or videos yet!" : "У цьому альбомі ще немає фото чи відео!",
    "Add photos to this album" : "Додайте фотографії до цього альбому",
    "Add photos to the album" : "Додайте фотографії в альбом",
    "Manage collaborators" : "Керуйте співавторами",
    "Save collaborators for this album." : "Зберегти співавторів для цього альбому.",
    "Cover photo for album {albumName}" : "Обкладинка для альбому {albumName}",
    "There is no album yet!" : "Альбому ще немає!",
    "This person could not be found" : "Цю людину не вдалося знайти",
    "Rename person" : "Перейменувати особу",
    "Merge with different person" : "Злитися з іншою людиною",
    "Download selected photos" : "Завантажте вибрані фото",
    "Favorite" : "До улюблених",
    "Remove from favorites" : "Вилучено з улюбленого",
    "Remove person" : "Видалити особу",
    "Name of this person" : "Ім'я цієї людини",
    "Merge person" : "Об’єднати особу",
    "_Remove photo from person_::_Remove photos from person_" : ["Видалити фото з особи","Видалити фотографії з особи","Видалити фотографії з особи","Видалити фотографії з особи"],
    "This might take some time depending on the size of your photo library." : "Це може зайняти деякий час залежно від розміру вашої бібліотеки фотографій.",
    "Recognized people will show up here" : "Тут відображатимуться розпізнані люди",
    "This folder does not exist" : "Цей каталог не існує",
    "Loading folders …" : "Завантаження папок…",
    "No photos in here" : "Тут немає світлин",
    "Failed to fetch albums list." : "Не вдалося отримати список альбомів.",
    "Shared albums" : "Альбоми із спільним доступом",
    "Cover photo for shared album {albumName}." : "Обкладинка для спільного альбому {albumName}.",
    "Back to tags overview" : "Назад до огляду тегів",
    "No photos with this tag yet" : "Фотографій із цим тегом ще немає",
    "No tags yet" : "Ще немає позначок",
    "Photos with tags will show up here" : "Світлини з позначками буде показано тут",
    "Popular tags" : "Популярні теги",
    "Add" : "Додати",
    "Create a new album" : "Створіть новий альбом",
    "Add selection to an album" : "Додайте виділене в альбом",
    "Add to album" : "Додати в альбом",
    "Delete selection" : "Видалити виділення",
    "Failed to fetch faces list." : "Не вдалося отримати список облич.",
    "All your media" : "Усі ваші зображення та відео",
    "Tagged photos" : "Світлини з позначками",
    "Failed to create {albumName}." : "Не вдалося створити {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Не вдалося перейменувати {currentAlbumName} на {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Не вдалося перейменувати {oldName} на {faceName}.",
    "Failed to delete {faceName}." : "Не вдалося видалити {faceName}.",
    "Failed to delete {fileId}." : "Не вдалося видалити {fileId}.",
    "Failed to delete {fileName}." : "Не вдалося видалити {fileName}.",
    "Failed to set favorite state for {fileId}." : "Не вдалося встановити улюблений стан для {fileId}.",
    "Failed to set favorite state for {fileName}." : "Не вдалося встановити улюблений стан для {fileName}.",
    "Your photos" : "Ваші світлини",
    "Your videos" : "Ваші відео",
    "Your folders" : "Ваші каталоги",
    "Settings" : "Налаштування"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
